==> Cosmos.uv7.22.tar.gz: UserHook/DisPara/FleshHist/setupenv.sh <==
#!/bin/sh 
###  don't touch next  line.   test is needed for sge job.
test  $# -eq  0  &&    source ../confirm.inc

#------------ probably need not touch next line
TOPDIR=$COSMOSTOP/UserHook/DisPara
export TOPDIR
#   dir to store execution command (ssh)  or submit command (sge)
EXECDIR=$TOPDIR/FleshHist/Exec
export EXECDIR
#     id  emmbeded in the command name as mentioned above. must not start with 
#    number for sge  jobs.
EXECID=p19cos0.7
export EXECID
#   
#         at which depth do you take histogram; the index must not exceed
#         really existing  depth index; otherwise, some 0 data will appear
#         in the hist data (Not fatal though).
HISTDEP='5  6  7  8  9  10  11 13/'
export HISTDEP
#         at which depth do you output individual ptcl info.
#         For > 10^17 eV, it's better to put 0 otherwise too huge output
#
INDIVDEP='0/'
export INDIVDEP
#   OUTPUT:   which histogram do you take.
#    first one is not for histogram, but for indiviual info.
#    (output x,y or only r)
#      1     2        3           4
#    recxy, tklat, tkelosslat, tkrespec,
#        5         6          7       8
#    tkrzspec, tkzfspec,  tkrfspec, tkefspec,
#          9         10         11         12      13      14 
#    tkertspec, tkrtspec,  tkrezspec, tkrzfspec, tkrefspec, tkarspec
#
OUTPUT='t t t t t t t t t t t t t t/' 
export OUTPUT
#     where param001 etc exist
PARAMDIR=$TOPDIR/FleshHist/ParamDir
export PARAMDIR
#     where to put data from each host
OUTDIR=$TOPDIR/Assemble/OutDir
export OUTDIR
#     where to put error message
ERRDIR=$TOPDIR/FleshHist/ErrDir
export ERRDIR

#  don't touch below.
#  if used from script, we skip the next lines.

if [ $# -eq  0 ] ; then
    confirm  $PARAMDIR
    confirm  $OUTDIR
    confirm  $ERRDIR
    confirm  $EXECDIR
fi

==> Cosmos.uv7.36.tar.gz: UserHook/DisPara/FleshHist/setupenv.sh <==
#!/bin/sh 
###  don't touch next  line.   test is needed for sge job.
test  $# -eq  0  &&    source ../confirm.inc

#------------ probably need not touch next line
TOPDIR=$COSMOSTOP/UserHook/DisPara
export TOPDIR
#   dir to store execution command (ssh)  or submit command (sge)
EXECDIR=$TOPDIR/FleshHist/Exec
export EXECDIR
#     id  emmbeded in the command name as mentioned above. must not start with 
#    number for sge  jobs.
EXECID=p15cos1.0H
export EXECID
#   
#         at which depth do you take histogram; the index must not exceed
#         really existing  depth index; otherwise, some 0 data will appear
#         in the hist data (Not fatal though).
HISTDEP='3 4 5  6  7  8  9  10/'
export HISTDEP
#         
#         
#  This is not used in DisPara.
INDIVDEP='0/'
export INDIVDEP
#   OUTPUT:   which histogram do you take.
#    first one is not for histogram, but for indiviual info.
#    (output x,y or only r)
#      1     2        3           4
#    recxy, tklat, tkelosslat, tkrespec,
#        5         6          7       8
#    tkrzspec, tkzfspec,  tkrfspec, tkefspec,
#          9         10         11         12      13      14 
#    tkertspec, tkrtspec,  tkrezspec, tkrzfspec, tkrefspec, tkarspec
#
OUTPUT='t t t t t t t t t t t t t t/' 
export OUTPUT
#     where param0001 etc exist
PARAMDIR=$TOPDIR/FleshHist/ParamDir
export PARAMDIR
#     where to put data from each host
#OUTDIR=$TOPDIR/Assemble/OutDir
OUTDIR=/tmp/$USER
export OUTDIR
#     where to put error message
ERRDIR=$TOPDIR/FleshHist/ErrDir
export ERRDIR

#  don't touch below.
#  if used from script, we skip the next lines.

if [ $# -eq  0 ] ; then
    confirm  $PARAMDIR
    confirm  $OUTDIR
    confirm  $ERRDIR
    confirm  $EXECDIR
#       check Sparam and copy primary file here
    if [ -f Sparam ]; then
	primaryf=` awk '$1=="PRIMARYFILE" {i1=index($0, qm) ;\
    i2=index(substr($0, i1+1), " "); print substr($0, i1+1,i2-1)}' qm="'" Sparam `
	echo "'"$primaryf"' seems to be the primary file used at SkelFlesh."
	echo "Now it is copied to this directory"
	cp ${COSMOSTOP}/UserHook/SkelFlesh/$primaryf ./
    else
	echo "There is no 'Sparam' file which is a standard copy of "
	echo " parameter file used in the SkeleFlesh process"
	echo " **** make a copy of parameter file  as Sparam and change Job='newskel' into"
	echo " Job='newflesh'"
	exit
    fi
fi
